@@ -5,8 +5,7 @@ use warnings;
 use Data::Dumper;
 use base 'Catalyst::Controller::HTML::FormFu';
 
-__PACKAGE__->config(
-    { 'Controller::HTML::FormFu' => { request_token_enable => 1 } } );
+__PACKAGE__->config( { 'Controller::HTML::FormFu' => { request_token_enable => 1 } } );
 
 sub token : Chained : CaptureArgs(0) {
     my ( $self, $c ) = @_;
@@ -19,7 +18,7 @@ sub form : Chained('token') : Args(0) : Form {
     my $form = $c->stash->{form};
 
     $form->elements( [ { name => 'basic_form', constraint => ['Required'] }, { type => "Submit" } ] );
-	$form->process($c->req);
+    $form->process( $c->req );
     if ( $form->submitted_and_valid ) {
         $c->res->body("VALID");
     }
@@ -31,8 +30,8 @@ sub dump_session : Local {
 }
 
 sub count_token : Local {
-	my ( $self, $c ) = @_;
-	$c->res->body( scalar @{ $c->session->{__token} || [] } );
+    my ( $self, $c ) = @_;
+    $c->res->body( scalar @{ $c->session->{__token} || [] } );
 }
 
 1;
